@@ -6,8 +6,8 @@ https://www.aug.ipp.mpg.de/aug/manuals/aug_sfutils
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.3.5'
-__date__    = '19.10.2021'
+__version__ = '0.3.6'
+__date__    = '20.10.2021'
 
 import sys, logging
 
@@ -20,10 +20,18 @@ logger.setLevel(logging.INFO)
 
 try: # wrapper classes, available only with afs-client and kerberos access
     from .ww import *
+except:
+    logger.warning('ww not loaded')
+    pass
+try:
     from .sfh import *
+except:
+    logger.warning('sfh not loaded')
+    pass
+try:
     from .journal import *
 except:
-    logger.warning('ww and sfh not loaded, SFREAD and EQU available')
+    logger.warning('journal not loaded')
     pass
 
 from .sfread import *
