@@ -2,7 +2,7 @@ import os, datetime, logging
 from struct import unpack
 import numpy as np
 
-from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
+from aug_sfutils import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
