@@ -1,7 +1,7 @@
 import os, datetime, warnings, logging
 import ctypes as ct
 import numpy as np
-from . import sfdics, str_byt
+from aug_sfutils import sfdics, str_byt
 
 logger = logging.getLogger('aug_sfutils.ww')
 
@@ -86,7 +86,7 @@ class WW:
             _space = ct.c_char_p( space )
 
             result = libddww.wwclose_(_error , self._diaref , _disp , _space , ldisp , lspace )
-            logger.info('Close: %d %d  Edition %d', result, error.value, self.edition.value)
+            logger.info('Close: ', result, error.value, ' Edition', self.edition.value)
             if getError( error ):
                 raise Exception('ww: Error Closing Shotfile')
             del self._diaref
